@@ -197,8 +197,7 @@ class SpikeCalcsGeneric(object):
     def trial_mean_fr(self, cluster: int) -> float:
         # Returns the trial mean firing rate for the cluster
         if self.duration is None:
-            warnings.warn("No duration provided, give me one!")
-            return
+            raise IndexError("No duration provided, give me one!")
         return self.n_spikes(cluster) / self.duration
 
     def mean_isi_range(self, cluster: int, n: int) -> float:
@@ -219,8 +218,7 @@ class SpikeCalcsGeneric(object):
             The mean of the autocorrelogram between 0 and n milliseconds
         """
         if cluster not in self.spk_clusters:
-            warnings.warn("Cluster not available")
-            return
+            raise IndexError("Cluster not available")
         bins = 201
         trange = np.array((-500, 500))
         t = self.spike_times[self.spk_clusters == cluster]
@@ -590,9 +588,11 @@ class SpikeCalcsTetrode(SpikeCalcsGeneric):
             fig = plt.figure()
             ax = fig.add_subplot(111)
             from matplotlib.colors import LogNorm
+            speed_mesh = speed_mesh[:-1, :-1]
+            spk_mesh = spk_mesh[:-1, :-1]
             ax.pcolormesh(
                 speed_mesh, spk_mesh, sm_binned_rate,
-                norm=LogNorm(), alpha=0.5, shading='flat', edgecolors='None')
+                norm=LogNorm(), alpha=0.5, shading='nearest', edgecolors='None')
             # overlay the smoothed binned rate against speed
             ax.plot(sp_bin_edges, binned_spk_rate, 'r')
             # do the linear regression and plot the fit too
@@ -754,7 +754,7 @@ class SpikeCalcsAxona(SpikeCalcsGeneric):
                     amps[:, c[0]], amps[:, c[1]],
                     range=myRange[:, c].T, bins=bins)
                 x, y = np.meshgrid(xe[0:-1], ye[0:-1])
-                grid[i].pcolormesh(x, y, h, cmap=clustCMap0, edgecolors='face')
+                grid[i].pcolormesh(x, y, h, cmap=clustCMap0, shading='nearest', edgecolors='face')
                 h, ye, xe = np.histogram2d(
                     amps[:, c[0]], amps[:, c[1]],
                     range=myRange[:, c].T, bins=bins)
@@ -765,7 +765,7 @@ class SpikeCalcsAxona(SpikeCalcsGeneric):
                 clustCMap._init()
                 clustCMap._lut[:, -1] = alpha_vals
                 grid[i].pcolormesh(
-                    x, y, h, cmap=clustCMap, edgecolors='face')
+                    x, y, h, cmap=clustCMap, shading='nearest', edgecolors='face')
             s = str(c[0]+1) + ' v ' + str(c[1]+1)
             grid[i].text(
                 0.05, 0.95, s, va='top', ha='left', size='small',
