@@ -262,18 +262,19 @@ class OpenEphysBase(FigureMaker):
         if self.path2PosData is not None:
             pos_data_type = getattr(self, 'pos_data_type', 'PosTracker')
             if pos_data_type == 'PosTracker':
+                print("Loading PosTracker data...")
                 pos_data = np.load(os.path.join(
                     self.path2PosData, 'data_array.npy'))
             if pos_data_type == 'TrackingPlugin':
+                print("Loading Tracking Plugin data...")
                 pos_data = loadTrackingPluginData(os.path.join(
                     self.path2PosData, 'data_array.npy'))
             pos_ts = np.load(os.path.join(
                 self.path2PosData, 'timestamps.npy'))
             pos_ts = np.ravel(pos_ts)
-            default_pos_sample_rate = np.floor(1/np.mean(np.diff(pos_ts) /
-                                               self.ap_sample_rate))
-            sample_rate = getattr(self, 'pos_sample_rate',
-                                  default_pos_sample_rate)
+            pos_timebase = getattr(self, 'pos_timebase', 3e4)
+            sample_rate = np.floor(1/np.mean(np.diff(pos_ts) /
+                                               pos_timebase))
             self.xyTS = pos_ts - recording_start_time
             pos_timebase = getattr(self, 'pos_timebase', 3e4)
             self.xyTS = self.xyTS / pos_timebase  # convert to seconds
@@ -384,7 +385,7 @@ class OpenEphysBase(FigureMaker):
         Returns the spike times in seconds of the given cluster
         '''
         times = self.kilodata.spk_times.T
-        return times[self.kilodata.spk_clusters == cluster].astype(np.int64)
+        return times[self.kilodata.spk_clusters == cluster].astype(np.int64) / self.ap_sample_rate
 
     def plotSummary(self, cluster: int, **kwargs):
         ts = self.getClusterSpikeTimes(cluster)
@@ -576,7 +577,7 @@ class OpenEphysNPX(OpenEphysBase):
                             self.sync_message_file = sync_file
                             print(f"Found sync_messages file at: {sync_file}")
 
-        self.loadPos()
+        super().loadPos()
 
         n_channels = getattr(self, 'n_channels', 384)
         trial_length = 0  # make sure a trial_length has a value
@@ -955,4 +956,4 @@ class OpenEphysBinary(OpenEphysBase):
         # OE's 'synchronised_timestamps.npy' should now take care of this
         self.ts = np.arange(
             self.recording_start_time, trial_length+self.recording_start_time,
-            1.0 / ap_sample_rate)
\ No newline at end of file
+            1.0 / ap_sample_rate)
